summaryrefslogtreecommitdiffstats
path: root/lua/lua-plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'lua/lua-plugin.h')
-rw-r--r--lua/lua-plugin.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/lua/lua-plugin.h b/lua/lua-plugin.h
index 9ae71b4..8116ae1 100644
--- a/lua/lua-plugin.h
+++ b/lua/lua-plugin.h
@@ -22,8 +22,8 @@ typedef struct{
} lua_command_candidate_t;
typedef struct{
- const char * lua_function_name;
- const char * description;
+ char * lua_function_name;
+ char * description;
/*< private, skip it, and register it into Special Table directly with * wildcard. >*/
/*
* list of input_trigger_strings;
@@ -90,7 +90,7 @@ const GArray * ibus_engine_plugin_get_available_commands(IBusEnginePlugin * plug
* command must be an 2-char long string.
* return the matched command.
*/
-lua_command_t * ibus_engine_plugin_lookup_command(IBusEnginePlugin * plugin, const char * command_name);
+const lua_command_t * ibus_engine_plugin_lookup_command(IBusEnginePlugin * plugin, const char * command_name);
/**
* retval int: returns the number of results,
@@ -102,11 +102,12 @@ int ibus_engine_plugin_call(IBusEnginePlugin * plugin, const char * lua_function
/**
* retrieve the retval string value. (value has been copied.)
*/
-const char * ibus_engine_plugin_get_retval(IBusEnginePlugin * plugin);
+const lua_command_candidate_t * ibus_engine_plugin_get_retval(IBusEnginePlugin * plugin);
/**
* retrieve the array of string values. (string values have been copied.)
*/
GArray * ibus_engine_plugin_get_retvals(IBusEnginePlugin * plugin);
+void ibus_engine_plugin_free(lua_command_candidate_t * candidate);
#endif
@@ -102,11 +102,12 @@ int ibus_engine_plugin_call(IBusEnginePlugin * plugin, const char * lua_function
/**
- * retrieve the array of string values. (string values have been copied.)
+ * retrieve the array of lua_command_candidate_t values. (string values have been copied.)
*/
GArray * ibus_engine_plugin_get_retvals(IBusEnginePlugin * plugin);